@@ -86,7 +86,8 @@ phe_proportion <- function(data, x, n, type="full", confidence=0.95, multiplier=
     if(!n_groups(data) == 1) {
         data <- data %>%
         summarise({{ x }} := sum({{ x }}),
-                  {{ n }} := sum({{ n }}))
+                  {{ n }} := sum({{ n }}),
+                  .groups = "keep")
     }
 
 
